<?xml version="1.0" encoding="utf-8"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">

<!-- Launch order stylesheet modified from competition result stylesheet by Mystifeid (26/9/12) -->

<!--  To see the input used for this xslt, check the "Create source.xml file 
      when creating report" menu item under the "Reports" menu in FsComp.
      When checked a .source.xml file is created each time you create a report.
      It shows the actual xml input to the xslt processor.
      This is helpfull if you like to modify this file.
      If using Vista or Win7 and you have installed FS (v1.31) to C:\Program Files\FS\
      (the default location) you will need to first right click the FS icon
      and select "Run as administrator" in order to be able to generate the xml source.
-->

 <xsl:output method="html" encoding="utf-8" indent="yes" />

 <!--  All <xsl:param ... elements will show as a field in a report dialog in 
       FS when creating reports. This means you can define param elements here 
       with a default value and set the value from FS when creating report.
 -->
 <xsl:param name="title">Launch Order</xsl:param>
 <xsl:param name="task">5</xsl:param>
 <xsl:param name="day_date">Thursday 27/09/12</xsl:param>
 <xsl:param name="reverse_x_pilots">20</xsl:param>

 <!--  The node-set that this variable returns is what is used to create the result list.-->
 
 <xsl:variable name="filter" select="/Fs/FsCompetition[1]/FsCompetitionResults[@top='all']/FsParticipant"/>

 <!-- record template, used for each pilot in the ranked list of pilots -->
 
 <xsl:template name="record">
  <xsl:variable name="pilot_id" select="@id"/>
  <tr class="fs_res_res_row" onmouseover="this.className = 'hover'" onmouseout="this.className='fs_res_res_row'" >
   <td class="fs_res" align="right">
    <xsl:value-of select="position()"/>
   </td>
   <td class="fs_res">
    <xsl:value-of select="/Fs/FsCompetition/FsParticipants/FsParticipant[@id=$pilot_id]/@name"/>
   </td>
   <td class="fs_res">
    <xsl:value-of select="@id"/>
   </td>
   <td class="fs_res">
    <xsl:value-of select="/Fs/FsCompetition/FsParticipants/FsParticipant[@id=$pilot_id]/@glider"/>
   </td>
   <td class="fs_res">
    <xsl:value-of select="/Fs/FsCompetition/FsParticipants/FsParticipant[@id=$pilot_id]/@glider_main_colors"/>
   </td>
  </tr>
 </xsl:template>

 <xsl:template match="/">
  <html>
   <head>
    <title><xsl:value-of select="$title"/> Task <xsl:value-of select="$task"/></title>
    <style type="text/css">
     .hover {/* for IE using onmouseover and onmouseout */ background:yellow;}
     tr.fs_res_res_row:hover {background:yellow;}
     div.fs_res {font-family:Verdana, Arial, Helvetica, sans-serif;font-size:xx-small;}
     table.fs_res {border:solid 1px gray;border-collapse:collapse;font-size:xx-small;}
     td.fs_res {border:solid 1px gray;vertical-align:top;padding:5px;}
     th.fs_res {border:solid 1px gray;vertical-align:center;}
    </style>
   </head>
   <body>
    <div>
     <div class="fs_res">
      <div class="fs_res" style="width:100%;font-size: xx-small;text-align:right;">
       <i>Report created: <xsl:value-of select="/Fs/FsCompetition/FsCompetitionResults[@top='all']/@ts"/></i>
      </div>
      <h2>
       <xsl:value-of select="/Fs/FsCompetition/@name"/>
      </h2>
      <p style="font-size:xx-small">
       <xsl:value-of select="/Fs/FsCompetition/@from"/> to <xsl:value-of select="/Fs/FsCompetition/@to"/>
      </p>
      <xsl:if test="string-length($title) > 0">
       <h2>
        <xsl:value-of select="$title"/>
        <xsl:if test="string-length($task) > 0">
         <xsl:value-of select="' Task '"/>
         <xsl:value-of select="$task"/>
        </xsl:if>
       </h2>
      </xsl:if>
      <xsl:if test="string-length($day_date) > 0">
       <h3>
        <xsl:value-of select="$day_date"/>
       </h3>
      </xsl:if>
      <h4>The positions of the first <xsl:value-of select="$reverse_x_pilots"/> pilots have been reversed</h4>	
      <br/>
      <table class="fs_res">
       <thead>
        <tr class="fs_res_res_row" onmouseover="this.className = 'hover'" onmouseout="this.className='fs_res_res_row'" >
         <th class="fs_res">#</th>
         <th class="fs_res">Name</th>
         <th class="fs_res">Id</th>
         <th class="fs_res">Glider</th>
         <th class="fs_res">Colours</th>
        </tr>
       </thead>
       <xsl:for-each select="$filter">
        <!-- participant rows -->              
        <xsl:sort data-type="number" order="ascending" select="$reverse_x_pilots+(number(not(position()&gt;$reverse_x_pilots)))*(1-position())+(number(not(position()&lt;($reverse_x_pilots+1))))*(position()-$reverse_x_pilots)"/>
        <xsl:call-template name="record"/>
       </xsl:for-each>
      </table>
     </div>
	</div>
   </body>
  </html>
 </xsl:template>
</xsl:stylesheet>
